use bevy::{
    app::{App, Startup, Update},
    asset::AssetServer,
    image::Image,
    input::ButtonInput,
    prelude::{Camera2d, Commands, Component, KeyCode, Query, Res, Transform, With},
    sprite::Sprite,
    time::Time,
    DefaultPlugins,
};

const CHARACTER_SPEED: f32 = 300.0;

#[derive(Debug, Component)]
struct Player {}

fn main() {
    println!("Hello, world!");

    App::new()
        .add_plugins(DefaultPlugins)
        .add_systems(Startup, load_character)
        .add_systems(Update, move_character)
        .run();
}

fn load_character(mut commands: Commands, asset_server: Res<AssetServer>) {
    commands.spawn(Camera2d::default());
    let image = asset_server.load::<Image>("character.png");
    commands.spawn((
        Sprite::from_image(image),
        Transform::from_xyz(0.0, 0.0, 0.0),
        Player {},
    ));
}

fn move_character(
    time: Res<Time>,
    mut character_transform: Query<&mut Transform, With<Player>>,
    keyboard_input: Res<ButtonInput<KeyCode>>,
) {
    let mut character_transform = character_transform.get_single_mut().unwrap();

    let translation = CHARACTER_SPEED * time.delta_secs();
    if keyboard_input.pressed(KeyCode::KeyW) {
        character_transform.translation.y += translation;
    }
    if keyboard_input.pressed(KeyCode::KeyS) {
        character_transform.translation.y -= translation;
    }
    if keyboard_input.pressed(KeyCode::KeyA) {
        character_transform.translation.x -= translation;
    }
    if keyboard_input.pressed(KeyCode::KeyD) {
        character_transform.translation.x += translation;
    }
}
